You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/16 19:23:02 UTC

[4/4] incubator-ignite git commit: # IGNITE-26 Replaced IgniteCheckedException with IgniteException on public API.

# IGNITE-26 Replaced IgniteCheckedException with IgniteException on public API.


Project: http://git-wip-us.apache.org/repos/asf/incubator-ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-ignite/commit/4307bca1
Tree: http://git-wip-us.apache.org/repos/asf/incubator-ignite/tree/4307bca1
Diff: http://git-wip-us.apache.org/repos/asf/incubator-ignite/diff/4307bca1

Branch: refs/heads/ignite-26
Commit: 4307bca1e17aebd5b71c5b7980e625978a236f00
Parents: 8bc850c
Author: sevdokimov <se...@gridgain.com>
Authored: Tue Dec 16 21:22:42 2014 +0300
Committer: sevdokimov <se...@gridgain.com>
Committed: Tue Dec 16 21:22:42 2014 +0300

----------------------------------------------------------------------
 .../compute/ComputeScheduleExample.java         |   2 +-
 .../failover/ComputeFailoverExample.java        |   2 +-
 .../examples/datagrid/CacheApiExample.java      |   2 +-
 .../datagrid/CachePopularNumbersExample.java    |   2 +-
 .../examples/messaging/MessagingExample.java    |   4 +-
 .../messaging/MessagingPingPongExample.java     |   4 +-
 .../streaming/StreamingCheckInExample.java      |   2 +-
 .../StreamingPopularNumbersExample.java         |   2 +-
 .../streaming/StreamingPriceBarsExample.java    |   2 +-
 .../StreamingRunningAverageExample.java         |   4 +-
 .../singlesplit/GridSingleSplitsLoadTest.java   |   2 +-
 .../GridClientTestPortableAffinityKeyTask.java  |   2 +-
 .../client/GridTaskSingleJobSplitAdapter.java   |   2 +-
 .../kernal/GridTaskEventSubjectIdSelfTest.java  |   2 +-
 .../ignite/messaging/MessagingListenActor.java  |  14 +-
 .../sharedfs/SharedFsCheckpointSpi.java         |   7 +-
 .../sharedfs/SharedFsTimeoutTask.java           |   4 +-
 .../discovery/tcp/TcpClientDiscoverySpi.java    |   2 +-
 .../spi/failover/always/AlwaysFailoverSpi.java  |   2 +-
 .../jobstealing/JobStealingFailoverSpi.java     |   2 +-
 .../spi/swapspace/file/FileSwapSpaceSpi.java    |   2 +-
 .../index/tree/StreamerTreeIndexProvider.java   |  10 +-
 .../window/StreamerBoundedTimeWindow.java       |   4 +-
 .../GridClientConnectionManagerAdapter.java     |   2 +-
 .../GridClientOptimizedMarshaller.java          |   6 +-
 .../impl/GridRouterCommandLineStartup.java      |   4 +-
 .../org/gridgain/grid/cache/GridCacheTx.java    |   4 +-
 .../cache/GridCacheTxHeuristicException.java    |   2 +-
 .../GridCacheRendezvousAffinityFunction.java    |  23 +-
 .../grid/kernal/GridKernalContextImpl.java      |   2 +-
 .../kernal/executor/GridExecutorService.java    |  30 +--
 .../ggfs/common/GridGgfsControlResponse.java    |   6 +-
 .../cache/GridCacheTxLocalAdapter.java          |   2 +-
 .../processors/cache/GridCacheTxProxyImpl.java  |   2 +-
 .../distributed/dht/GridDhtTxFinishFuture.java  |   2 +-
 .../query/GridCacheDistributedQueryManager.java |   4 +-
 .../processors/ggfs/GridGgfsAsyncImpl.java      |   8 +-
 .../kernal/processors/ggfs/GridGgfsImpl.java    | 145 +++++++----
 .../ggfs/GridGgfsInputStreamImpl.java           |   2 +-
 .../processors/ggfs/GridGgfsMetaManager.java    |   9 +-
 .../kernal/processors/ggfs/GridGgfsServer.java  |   4 +-
 .../ggfs/IgniteFsOutputStreamImpl.java          |   2 +-
 .../cache/GridCacheQueryCommandHandler.java     |   6 +-
 .../handlers/task/GridTaskCommandHandler.java   |   4 +-
 .../service/GridServiceNotFoundException.java   |   2 +-
 .../grid/util/future/GridEmbeddedFuture.java    |  10 +-
 .../util/gridify/GridifyArgumentBuilder.java    |   6 +-
 .../grid/util/gridify/GridifyJobAdapter.java    |  12 +-
 .../org/gridgain/grid/util/lang/GridFunc.java   |  11 +-
 .../org/gridgain/jdbc/util/GridJdbcUtils.java   |   4 +-
 .../optimized/GridOptimizedMarshallerTest.java  |   2 +-
 .../GridOptimizedObjectStreamSelfTest.java      |   2 +-
 ...heckpointSpiMultipleDirectoriesSelfTest.java |   2 +-
 .../tcp/GridCacheDhtLockBackupSelfTest.java     |   2 +-
 .../tcp/GridOrderedMessageCancelSelfTest.java   |   2 +-
 .../tcp/GridTcpCommunicationSpiLanTest.java     |   2 +-
 ...cpCommunicationSpiMultithreadedSelfTest.java |   6 +-
 ...RobinLoadBalancingSpiNotPerTaskSelfTest.java |   2 +-
 .../index/GridStreamerIndexSelfTest.java        |   8 +-
 .../org/gridgain/grid/GridTestJobResult.java    |   6 +-
 .../ggfs/GridGgfsEventsAbstractSelfTest.java    |   2 +-
 .../GridAlwaysFailoverSpiFailSelfTest.java      |   4 +-
 .../kernal/GridCancelOnGridStopSelfTest.java    |   4 +-
 .../GridCancelledJobsMetricsSelfTest.java       |   6 +-
 .../grid/kernal/GridCommunicationSelfTest.java  |   2 +-
 .../GridContinuousJobAnnotationSelfTest.java    |   6 +-
 .../GridContinuousJobSiblingsSelfTest.java      |   2 +-
 .../grid/kernal/GridContinuousTaskSelfTest.java |   6 +-
 .../GridDeploymentMultiThreadedSelfTest.java    |   2 +-
 .../grid/kernal/GridDeploymentSelfTest.java     |   2 +-
 .../GridEventStorageCheckAllEventsSelfTest.java |   2 +-
 .../GridExplicitImplicitDeploymentSelfTest.java |   3 +-
 .../grid/kernal/GridFactoryVmShutdownTest.java  |   2 +-
 .../GridFailoverCustomTopologySelfTest.java     |   2 +-
 .../grid/kernal/GridFailoverSelfTest.java       |   4 +-
 .../GridFailoverTaskWithPredicateSelfTest.java  |   4 +-
 .../kernal/GridFailoverTopologySelfTest.java    |   4 +-
 .../kernal/GridJobMasterLeaveAwareSelfTest.java |   2 +-
 .../grid/kernal/GridJobStealingSelfTest.java    |   2 +-
 .../GridJobStealingZeroActiveJobsSelfTest.java  |   2 +-
 .../grid/kernal/GridLifecycleBeanSelfTest.java  |   2 +-
 .../grid/kernal/GridListenActorSelfTest.java    |   1 +
 .../grid/kernal/GridMultipleSpisSelfTest.java   |   4 +-
 .../GridMultipleVersionsDeploymentSelfTest.java |   2 +-
 .../GridMultithreadedJobStealingSelfTest.java   |   4 +-
 .../kernal/GridRuntimeExceptionSelfTest.java    |   8 +-
 .../grid/kernal/GridSpiExceptionSelfTest.java   |   2 +-
 .../grid/kernal/GridStopWithCancelSelfTest.java |   4 +-
 .../grid/kernal/GridStopWithWaitSelfTest.java   |   4 +-
 .../GridTaskContinuousMapperSelfTest.java       |  12 +-
 .../kernal/GridTaskInstantiationSelfTest.java   |   2 +-
 .../GridCheckpointManagerAbstractSelfTest.java  |  30 +--
 ...idCommunicationManagerListenersSelfTest.java |   2 +-
 .../cache/GridCacheAbstractFullApiSelfTest.java |  14 +-
 .../cache/GridCacheAffinityRoutingSelfTest.java |   2 +-
 .../GridCacheConcurrentTxMultiNodeTest.java     |   4 +-
 .../GridCacheGroupLockFailoverSelfTest.java     |   2 +-
 .../cache/GridCacheGroupLockPutTask.java        |  18 +-
 .../cache/GridCachePutAllFailoverSelfTest.java  |   6 +-
 .../processors/cache/GridCacheStopSelfTest.java |   2 +-
 .../cache/GridCacheTxMultiNodeAbstractTest.java | 257 ++++++++++---------
 ...cheAtomicReferenceMultiNodeAbstractTest.java |  94 ++++---
 ...GridCacheQueueMultiNodeAbstractSelfTest.java |  40 ++-
 ...CacheQueueRotativeMultiNodeAbstractTest.java |  57 +++-
 ...dCacheSequenceMultiNodeAbstractSelfTest.java |  57 ++--
 ...dCachePartitionedQueueEntryMoveSelfTest.java |  20 +-
 .../dht/GridCacheDhtPreloadUnloadSelfTest.java  |  12 +-
 ...achePartitionedPreloadLifecycleSelfTest.java |  15 +-
 .../closure/GridClosureProcessorSelfTest.java   |   2 +-
 .../continuous/GridEventConsumeSelfTest.java    |   4 +-
 ...heGgfsPerBlockLruEvictionPolicySelfTest.java |   2 +-
 .../ggfs/GridGgfsAbstractSelfTest.java          |  44 ++--
 .../ggfs/GridGgfsDualAbstractSelfTest.java      |  12 +-
 .../ggfs/GridGgfsFileInfoSelfTest.java          |   8 +-
 .../GridGgfsProcessorValidationSelfTest.java    |   2 +-
 .../cache/GridCacheCommandHandlerSelfTest.java  |   4 +-
 .../GridServiceProcessorAbstractSelfTest.java   |   2 +-
 .../lang/GridFutureListenPerformanceTest.java   |   2 +-
 ...idFileSwapSpaceSpiMultithreadedLoadTest.java |   2 +-
 .../p2p/GridP2PLocalDeploymentSelfTest.java     |   2 +-
 .../GridP2PMissedResourceCacheSizeSelfTest.java |   6 +-
 .../grid/p2p/GridP2PTimeoutSelfTest.java        |   4 +-
 .../GridSessionCheckpointAbstractSelfTest.java  |   4 +-
 .../GridSessionCollisionSpiSelfTest.java        |   2 +-
 .../session/GridSessionJobFailoverSelfTest.java |   6 +-
 ...GridSessionJobWaitTaskAttributeSelfTest.java |   2 +-
 .../GridSessionSetFutureAttributeSelfTest.java  |   2 +-
 ...nSetFutureAttributeWaitListenerSelfTest.java |   2 +-
 .../GridSessionSetJobAttribute2SelfTest.java    |   2 +-
 ...GridSessionSetJobAttributeOrderSelfTest.java |   4 +-
 .../GridSessionSetJobAttributeSelfTest.java     |   2 +-
 ...sionSetJobAttributeWaitListenerSelfTest.java |   2 +-
 .../GridSessionSetTaskAttributeSelfTest.java    |   2 +-
 ...GridSessionTaskWaitJobAttributeSelfTest.java |   2 +-
 .../GridSessionWaitAttributeSelfTest.java       |   6 +-
 .../util/future/GridEmbeddedFutureSelfTest.java |   2 +-
 .../future/GridFutureListenPerformanceTest.java |   2 +-
 .../offheap/GridOffHeapMapAbstractSelfTest.java |   2 +-
 ...idOffHeapPartitionedMapAbstractSelfTest.java |   2 +-
 .../colocation/GridTestLifecycleBean.java       |   8 +-
 .../communication/GridIoManagerBenchmark0.java  |   2 +-
 .../multisplit/GridMultiSplitsLoadTest.java     |   2 +-
 .../GridMultiSplitsRedeployLoadTest.java        |   2 +-
 .../GridSingleSplitsRedeployLoadTest.java       |   2 +-
 .../direct/session/GridSessionLoadTestTask.java |   2 +-
 .../gridgain/loadtests/dsi/GridDsiClient.java   |   3 +-
 .../loadtests/dsi/GridDsiLifecycleBean.java     |   8 +-
 .../job/GridJobExecutionLoadTestClient.java     |   6 +-
 ...GridJobExecutionLoadTestClientSemaphore.java |   4 +-
 .../job/GridJobExecutionSingleNodeLoadTest.java |   2 +-
 .../loadtests/job/GridJobLoadTestJob.java       |   2 +-
 .../loadtests/job/GridJobLoadTestSubmitter.java |   6 +-
 .../mapper/GridContinuousMapperTask1.java       |   4 +-
 .../loadtests/streamer/EventClosure.java        |   2 +-
 .../hadoop/GridHadoopMapReduceTest.java         |   2 +-
 .../GridCacheAtomicFieldsQuerySelfTest.java     |   2 +-
 .../grid/kernal/GridScheduleSelfTest.java       |  16 +-
 .../GridResourceConcurrentUndeploySelfTest.java |   2 +-
 .../GridResourceFieldInjectionSelfTest.java     |   8 +-
 .../resource/GridResourceIocSelfTest.java       |   2 +-
 ...GridResourceIsolatedClassLoaderSelfTest.java |   2 +-
 .../GridResourceIsolatedTaskSelfTest.java       |   2 +-
 .../GridResourceSharedUndeploySelfTest.java     |   2 +-
 .../resource/GridServiceInjectionSelfTest.java  |   4 +-
 .../grid/p2p/GridP2PDisabledSelfTest.java       |   2 +-
 165 files changed, 802 insertions(+), 608 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java b/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
index e80e1f2..37b33bf 100644
--- a/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
+++ b/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
@@ -58,7 +58,7 @@ public class ComputeScheduleExample {
                                 }
                             );
                         }
-                        catch (IgniteCheckedException e) {
+                        catch (IgniteException e) {
                             throw new IgniteException(e);
                         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java b/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
index dff46a3..436f0c2 100644
--- a/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
+++ b/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
@@ -119,7 +119,7 @@ public class ComputeFailoverExample {
 
                 return sum;
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 throw new GridClosureException(e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java b/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
index a30c20f..1564af1 100644
--- a/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
+++ b/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
@@ -80,7 +80,7 @@ public class CacheApiExample {
                 try {
                     System.out.println("Put operation completed [previous-value=" + fut.get() + ']');
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     e.printStackTrace();
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java b/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
index 69a1216..aee3780 100644
--- a/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
+++ b/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
@@ -137,7 +137,7 @@ public class CachePopularNumbersExample {
 
                     System.out.println("----------------");
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     e.printStackTrace();
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java b/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java
index fa51a78..4e0ce98 100644
--- a/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java
+++ b/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java
@@ -106,7 +106,7 @@ public final class MessagingExample {
                 try {
                     g.message(g.cluster().forNodeId(nodeId)).send(TOPIC.ORDERED, msg);
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     e.printStackTrace();
                 }
 
@@ -125,7 +125,7 @@ public final class MessagingExample {
                 try {
                     g.message(g.cluster().forNodeId(nodeId)).send(TOPIC.UNORDERED, msg);
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     e.printStackTrace();
                 }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java b/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
index ed9585b..e164a2b 100644
--- a/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
+++ b/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
@@ -73,7 +73,7 @@ public class MessagingPingPongExample {
 
                         return false; // Unsubscribe.
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         throw new GridClosureException(e);
                     }
                 }
@@ -105,7 +105,7 @@ public class MessagingPingPongExample {
 
                         return true; // Continue listening.
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         throw new GridClosureException(e);
                     }
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/streaming/StreamingCheckInExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/streaming/StreamingCheckInExample.java b/examples/src/main/java/org/gridgain/examples/streaming/StreamingCheckInExample.java
index d0826e9..3920c84 100644
--- a/examples/src/main/java/org/gridgain/examples/streaming/StreamingCheckInExample.java
+++ b/examples/src/main/java/org/gridgain/examples/streaming/StreamingCheckInExample.java
@@ -214,7 +214,7 @@ public class StreamingCheckInExample {
 
                     System.out.print(sb.toString());
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     e.printStackTrace();
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/streaming/StreamingPopularNumbersExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/streaming/StreamingPopularNumbersExample.java b/examples/src/main/java/org/gridgain/examples/streaming/StreamingPopularNumbersExample.java
index e4bf863..b385da6 100644
--- a/examples/src/main/java/org/gridgain/examples/streaming/StreamingPopularNumbersExample.java
+++ b/examples/src/main/java/org/gridgain/examples/streaming/StreamingPopularNumbersExample.java
@@ -178,7 +178,7 @@ public class StreamingPopularNumbersExample {
 
                     System.out.println("----------------");
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     e.printStackTrace();
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/streaming/StreamingPriceBarsExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/streaming/StreamingPriceBarsExample.java b/examples/src/main/java/org/gridgain/examples/streaming/StreamingPriceBarsExample.java
index 23e9443..82d352f 100644
--- a/examples/src/main/java/org/gridgain/examples/streaming/StreamingPriceBarsExample.java
+++ b/examples/src/main/java/org/gridgain/examples/streaming/StreamingPriceBarsExample.java
@@ -158,7 +158,7 @@ public class StreamingPriceBarsExample {
 
                     System.out.println("-----------------");
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     e.printStackTrace();
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/examples/src/main/java/org/gridgain/examples/streaming/StreamingRunningAverageExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/gridgain/examples/streaming/StreamingRunningAverageExample.java b/examples/src/main/java/org/gridgain/examples/streaming/StreamingRunningAverageExample.java
index cd29378..2432557 100644
--- a/examples/src/main/java/org/gridgain/examples/streaming/StreamingRunningAverageExample.java
+++ b/examples/src/main/java/org/gridgain/examples/streaming/StreamingRunningAverageExample.java
@@ -93,7 +93,7 @@ public class StreamingRunningAverageExample {
 
                         System.out.println("Got streamer query result [avg=" + avg + ", idealAvg=" + (rndRange / 2) + ']');
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         System.out.println("Failed to execute streamer query: " + e);
                     }
                 }
@@ -110,7 +110,7 @@ public class StreamingRunningAverageExample {
                     try {
                         streamer.addEvent(rnd.nextInt(rndRange));
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         System.out.println("Failed to add streamer event: " + e);
                     }
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
----------------------------------------------------------------------
diff --git a/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java b/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
index 0266d3a..eed3f4f 100644
--- a/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
+++ b/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
@@ -114,7 +114,7 @@ public class GridSingleSplitsLoadTest extends GridCommonAbstractTest {
                         if (taskCnt % 500 == 0)
                             info(stats.toString());
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         error("Failed to execute grid task.", e);
 
                         fail();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/clients/src/test/java/org/gridgain/client/GridClientTestPortableAffinityKeyTask.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/client/GridClientTestPortableAffinityKeyTask.java b/modules/clients/src/test/java/org/gridgain/client/GridClientTestPortableAffinityKeyTask.java
index ae7d11f..8c711b2 100644
--- a/modules/clients/src/test/java/org/gridgain/client/GridClientTestPortableAffinityKeyTask.java
+++ b/modules/clients/src/test/java/org/gridgain/client/GridClientTestPortableAffinityKeyTask.java
@@ -39,7 +39,7 @@ public class GridClientTestPortableAffinityKeyTask extends ComputeTaskAdapter<Ob
                 }, node);
         }
 
-        throw new IgniteCheckedException("Failed to find local node in task topology: " + clusterNodes);
+        throw new IgniteException("Failed to find local node in task topology: " + clusterNodes);
     }
 
     /** {@inheritDoc} */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/clients/src/test/java/org/gridgain/client/GridTaskSingleJobSplitAdapter.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/client/GridTaskSingleJobSplitAdapter.java b/modules/clients/src/test/java/org/gridgain/client/GridTaskSingleJobSplitAdapter.java
index 53d205d..82767cd 100644
--- a/modules/clients/src/test/java/org/gridgain/client/GridTaskSingleJobSplitAdapter.java
+++ b/modules/clients/src/test/java/org/gridgain/client/GridTaskSingleJobSplitAdapter.java
@@ -43,7 +43,7 @@ public abstract class GridTaskSingleJobSplitAdapter<T, R> extends ComputeTaskSpl
         ComputeJobResult res = results.get(0);
 
         if (res.isCancelled())
-            throw new IgniteCheckedException("Reduce receives failed job.");
+            throw new IgniteException("Reduce receives failed job.");
 
         return res.getData();
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java b/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java
index d294460..1f86599 100644
--- a/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java
+++ b/modules/clients/src/test/java/org/gridgain/grid/kernal/GridTaskEventSubjectIdSelfTest.java
@@ -355,7 +355,7 @@ public class GridTaskEventSubjectIdSelfTest extends GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Nullable @Override public Object reduce(List<ComputeJobResult> results) throws IgniteException {
-            throw new IgniteCheckedException("Task failed.");
+            throw new IgniteException("Task failed.");
         }
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
index 3c93370..ffb4730 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.marshaller.*;
 import org.apache.ignite.resources.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.checkpoint.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
@@ -302,7 +301,7 @@ public class SharedFsCheckpointSpi extends IgniteSpiAdapter implements Checkpoin
                                 log.debug("Registered existing checkpoint from: " + file.getAbsolutePath());
                         }
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         U.error(log, "Failed to unmarshal objects in checkpoint file (ignoring): " +
                             file.getAbsolutePath(), e);
                     }
@@ -363,7 +362,7 @@ public class SharedFsCheckpointSpi extends IgniteSpiAdapter implements Checkpoin
                         null
                     : null;
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 throw new IgniteSpiException("Failed to unmarshal objects in checkpoint file: " +
                     file.getAbsolutePath(), e);
             }
@@ -413,7 +412,7 @@ public class SharedFsCheckpointSpi extends IgniteSpiAdapter implements Checkpoin
                     throw new IgniteSpiException("Failed to write checkpoint data into file: " +
                         file.getAbsolutePath(), e);
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 throw new IgniteSpiException("Failed to marshal checkpoint data into file: " +
                     file.getAbsolutePath(), e);
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java
index 442caef..ff6c4c8 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsTimeoutTask.java
@@ -12,9 +12,9 @@ package org.apache.ignite.spi.checkpoint.sharedfs;
 import org.apache.ignite.*;
 import org.apache.ignite.marshaller.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.checkpoint.*;
 import org.gridgain.grid.util.typedef.internal.*;
+
 import java.io.*;
 import java.util.*;
 
@@ -106,7 +106,7 @@ class SharedFsTimeoutTask extends IgniteSpiThread {
                         if (timeData.getLastAccessTime() != file.lastModified())
                             timeData.setExpireTime(SharedFsUtils.read(file, marshaller, log).getExpireTime());
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         U.error(log, "Failed to marshal/unmarshal in checkpoint file: " + file.getAbsolutePath(), e);
 
                         continue;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java
index bf1b783..a3c66d8 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpClientDiscoverySpi.java
@@ -741,7 +741,7 @@ public class TcpClientDiscoverySpi extends TcpDiscoverySpiAdapter implements Tcp
 
                         msgWrk.addMessage(msg);
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         if (log.isDebugEnabled())
                             U.error(log, "Failed to read message [sock=" + sock0 + ", locNodeId=" + locNodeId +
                                 ", rmtNodeId=" + nodeId + ']', e);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java
index 46a071b..7c1cc21 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/failover/always/AlwaysFailoverSpi.java
@@ -219,7 +219,7 @@ public class AlwaysFailoverSpi extends IgniteSpiAdapter implements FailoverSpi,
 
             return node;
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             U.error(log, "Failed to get next balanced node for failover: " + ctx, e);
 
             return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java
index 8fea012..20662b6 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/failover/jobstealing/JobStealingFailoverSpi.java
@@ -324,7 +324,7 @@ public class JobStealingFailoverSpi extends IgniteSpiAdapter implements Failover
 
             return thief;
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             U.error(log, "Failed to get next balanced node for failover: " + ctx, e);
 
             return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
index 45406dc..c27eda1 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/swapspace/file/FileSwapSpaceSpi.java
@@ -556,7 +556,7 @@ public class FileSwapSpaceSpi extends IgniteSpiAdapter implements SwapSpaceSpi,
             try {
                 keyBytes = marsh.marshal(key.key());
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 throw new IgniteSpiException("Failed to marshal key: " + key.key(), e);
             }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/streamer/index/tree/StreamerTreeIndexProvider.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/streamer/window/StreamerBoundedTimeWindow.java b/modules/core/src/main/java/org/apache/ignite/streamer/window/StreamerBoundedTimeWindow.java
index 2ab5a9d..e6ed797 100644
--- a/modules/core/src/main/java/org/apache/ignite/streamer/window/StreamerBoundedTimeWindow.java
+++ b/modules/core/src/main/java/org/apache/ignite/streamer/window/StreamerBoundedTimeWindow.java
@@ -96,12 +96,12 @@ public class StreamerBoundedTimeWindow<E> extends StreamerWindowAdapter<E> {
     /** {@inheritDoc} */
     @Override public void checkConfiguration() throws IgniteException {
         if (timeInterval <= 0)
-            throw new IgniteCheckedException("Failed to initialize window (timeInterval must be positive): [windowClass=" +
+            throw new IgniteException("Failed to initialize window (timeInterval must be positive): [windowClass=" +
                 getClass().getSimpleName() + ", maxSize=" + maxSize + ", timeInterval=" + timeInterval + ", unique=" +
                 unique + ']');
 
         if (maxSize < 0)
-            throw new IgniteCheckedException("Failed to initialize window (maximumSize cannot be negative): [windowClass=" +
+            throw new IgniteException("Failed to initialize window (maximumSize cannot be negative): [windowClass=" +
                 getClass().getSimpleName() + ", maxSize=" + maxSize + ", timeInterval=" + timeInterval + ", unique=" +
                 unique + ']');
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/client/impl/connection/GridClientConnectionManagerAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/client/impl/connection/GridClientConnectionManagerAdapter.java b/modules/core/src/main/java/org/gridgain/client/impl/connection/GridClientConnectionManagerAdapter.java
index a5a27a6..023431a 100644
--- a/modules/core/src/main/java/org/gridgain/client/impl/connection/GridClientConnectionManagerAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/client/impl/connection/GridClientConnectionManagerAdapter.java
@@ -473,7 +473,7 @@ abstract class GridClientConnectionManagerAdapter implements GridClientConnectio
                 if (cfg.getSecurityCredentialsProvider() != null)
                     cred = cfg.getSecurityCredentialsProvider().credentials();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 throw new GridClientException("Failed to obtain client credentials.", e);
             }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/client/marshaller/optimized/GridClientOptimizedMarshaller.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/client/marshaller/optimized/GridClientOptimizedMarshaller.java b/modules/core/src/main/java/org/gridgain/client/marshaller/optimized/GridClientOptimizedMarshaller.java
index 5a63d93..1e14aab 100644
--- a/modules/core/src/main/java/org/gridgain/client/marshaller/optimized/GridClientOptimizedMarshaller.java
+++ b/modules/core/src/main/java/org/gridgain/client/marshaller/optimized/GridClientOptimizedMarshaller.java
@@ -55,7 +55,7 @@ public class GridClientOptimizedMarshaller implements GridClientMarshaller {
         try {
             opMarsh = new IgniteOptimizedMarshaller(requireSer, clsNames, clsNamesPath, poolSize);
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             throw new IOException(e);
         }
     }
@@ -79,7 +79,7 @@ public class GridClientOptimizedMarshaller implements GridClientMarshaller {
 
             return buf;
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             throw new IOException(e);
         }
     }
@@ -89,7 +89,7 @@ public class GridClientOptimizedMarshaller implements GridClientMarshaller {
         try {
             return opMarsh.unmarshal(bytes, null);
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             throw new IOException(e);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/client/router/impl/GridRouterCommandLineStartup.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/client/router/impl/GridRouterCommandLineStartup.java b/modules/core/src/main/java/org/gridgain/client/router/impl/GridRouterCommandLineStartup.java
index 4a03f9c..87fd016 100644
--- a/modules/core/src/main/java/org/gridgain/client/router/impl/GridRouterCommandLineStartup.java
+++ b/modules/core/src/main/java/org/gridgain/client/router/impl/GridRouterCommandLineStartup.java
@@ -61,7 +61,7 @@ public class GridRouterCommandLineStartup {
                 try {
                     tcpRouter.start();
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     U.error(log, "Failed to start TCP router on port " + tcpCfg.getPort() + ": " + e.getMessage(), e);
 
                     tcpRouter = null;
@@ -78,7 +78,7 @@ public class GridRouterCommandLineStartup {
             try {
                 tcpRouter.stop();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 U.error(log, "Error while stopping the router.", e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTx.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTx.java b/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTx.java
index 473d5b9..807646c 100644
--- a/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTx.java
+++ b/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTx.java
@@ -223,9 +223,9 @@ public interface GridCacheTx extends GridMetadataAware, AutoCloseable {
     /**
      * Ends the transaction. Transaction will be rolled back if it has not been committed.
      *
-     * @throws IgniteCheckedException If transaction could not be gracefully ended.
+     * @throws IgniteException If transaction could not be gracefully ended.
      */
-    @Override public void close() throws IgniteException;
+    @Override public void close() throws IgniteCheckedException;
 
     /**
      * Asynchronously commits this transaction by initiating {@code two-phase-commit} process.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTxHeuristicException.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTxHeuristicException.java b/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTxHeuristicException.java
index 4633659..0ed873f 100644
--- a/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTxHeuristicException.java
+++ b/modules/core/src/main/java/org/gridgain/grid/cache/GridCacheTxHeuristicException.java
@@ -18,7 +18,7 @@ import org.apache.ignite.*;
  * integrity, by invalidating all values participating in this transaction
  * on remote nodes.
  */
-public class GridCacheTxHeuristicException extends IgniteCheckedException {
+public class GridCacheTxHeuristicException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/cache/affinity/rendezvous/GridCacheRendezvousAffinityFunction.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/cache/affinity/rendezvous/GridCacheRendezvousAffinityFunction.java b/modules/core/src/main/java/org/gridgain/grid/cache/affinity/rendezvous/GridCacheRendezvousAffinityFunction.java
index ee3cdb6..47c9557 100644
--- a/modules/core/src/main/java/org/gridgain/grid/cache/affinity/rendezvous/GridCacheRendezvousAffinityFunction.java
+++ b/modules/core/src/main/java/org/gridgain/grid/cache/affinity/rendezvous/GridCacheRendezvousAffinityFunction.java
@@ -282,20 +282,19 @@ public class GridCacheRendezvousAffinityFunction implements GridCacheAffinityFun
         for (ClusterNode node : nodes) {
             Object nodeHash = hashIdRslvr.resolve(node);
 
-            try {
-                ByteArrayOutputStream out = new ByteArrayOutputStream();
+            ByteArrayOutputStream out = new ByteArrayOutputStream();
 
-                byte[] nodeHashBytes = marshaller.marshal(nodeHash);
+            byte[] nodeHashBytes = marshaller.marshal(nodeHash);
 
-                out.write(nodeHashBytes, 0, nodeHashBytes.length); // Avoid IOException.
-                out.write(U.intToBytes(part), 0, 4); // Avoid IOException.
+            out.write(nodeHashBytes, 0, nodeHashBytes.length); // Avoid IOException.
+            out.write(U.intToBytes(part), 0, 4); // Avoid IOException.
 
-                d.reset();
+            d.reset();
 
-                byte[] bytes = d.digest(out.toByteArray());
+            byte[] bytes = d.digest(out.toByteArray());
 
-                long hash =
-                      (bytes[0] & 0xFFL)
+            long hash =
+                (bytes[0] & 0xFFL)
                     | ((bytes[1] & 0xFFL) << 8)
                     | ((bytes[2] & 0xFFL) << 16)
                     | ((bytes[3] & 0xFFL) << 24)
@@ -304,11 +303,7 @@ public class GridCacheRendezvousAffinityFunction implements GridCacheAffinityFun
                     | ((bytes[6] & 0xFFL) << 48)
                     | ((bytes[7] & 0xFFL) << 56);
 
-                lst.add(F.t(hash, node));
-            }
-            catch (IgniteCheckedException e) {
-                throw new IgniteException(e);
-            }
+            lst.add(F.t(hash, node));
         }
 
         Collections.sort(lst, COMPARATOR);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/GridKernalContextImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/GridKernalContextImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/GridKernalContextImpl.java
index b6f4ac8..ef2c182 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/GridKernalContextImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/GridKernalContextImpl.java
@@ -333,7 +333,7 @@ public class GridKernalContextImpl extends GridMetadataAwareAdapter implements G
         try {
             spring = SPRING.create(false);
         }
-        catch (IgniteCheckedException ignored) {
+        catch (IgniteException ignored) {
             if (log != null && log.isDebugEnabled())
                 log.debug("Failed to load spring component, will not be able to extract userVersion from " +
                     "META-INF/gridgain.xml.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/executor/GridExecutorService.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/executor/GridExecutorService.java b/modules/core/src/main/java/org/gridgain/grid/kernal/executor/GridExecutorService.java
index 8be6cc1..c4c0107 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/executor/GridExecutorService.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/executor/GridExecutorService.java
@@ -158,7 +158,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
             try {
                 task.cancel();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 U.error(log, "Failed to cancel task: " + task, e);
             }
         }
@@ -212,7 +212,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
                 return false;
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 U.error(log, "Failed to get task result: " + fut, e);
 
                 if (e.getCause() instanceof InterruptedException)
@@ -238,7 +238,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
             return addFuture(comp.<T>future());
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             // Should not be thrown since uses asynchronous execution.
             return addFuture(new GridFinishedFutureEx<T>(e));
         }
@@ -256,7 +256,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
             comp.run(task);
 
             IgniteFuture<T> fut = comp.future().chain(new CX1<IgniteFuture<?>, T>() {
-                @Override public T applyx(IgniteFuture<?> fut) throws IgniteCheckedException {
+                @Override public T applyx(IgniteFuture<?> fut) throws IgniteException {
                     fut.get();
 
                     return res;
@@ -265,7 +265,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
             return addFuture(fut);
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             // Should not be thrown since uses asynchronous execution.
             return addFuture(new GridFinishedFutureEx<T>(e));
         }
@@ -284,7 +284,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
             return addFuture(comp.future());
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             // Should not be thrown since uses asynchronous execution.
             return addFuture(new GridFinishedFutureEx<>(e));
         }
@@ -353,7 +353,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
                 fut = comp.future();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 // Should not be thrown since uses asynchronous execution.
                 fut = new GridFinishedFutureEx<>(e);
             }
@@ -376,7 +376,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
                     cancelFuture(fut);
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     if (e.getCause() instanceof InterruptedException) {
                         // This invokeAll() method was interrupted (therefore, need to cancel all tasks).
                         // Note: that execution may be interrupted on remote node. Possible bug.
@@ -418,7 +418,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
         try {
             fut.cancel();
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             U.error(log, "Failed to cancel task: " + fut, e);
         }
     }
@@ -493,7 +493,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
                 fut = comp.future();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 // Should not be thrown since uses asynchronous execution.
                 fut = new GridFinishedFutureEx<>(e);
             }
@@ -528,7 +528,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
                     cancel = true;
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     // This invokeAll() method was interrupted (therefore, need to cancel all tasks).
                     // Note: that execution may be interrupted on remote node. Possible bug.
                     if (e.getCause() instanceof InterruptedException)
@@ -573,7 +573,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
             addFuture(comp.future());
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             // Should not be thrown since uses asynchronous execution.
             addFuture(new GridFinishedFutureEx(e));
         }
@@ -647,7 +647,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
             try {
                 fut.cancel();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 U.error(log, "Failed to cancel task: " + fut, e);
             }
 
@@ -674,7 +674,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
 
                 return res;
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 // Task cancellation may cause throwing exception.
                 if (fut.isCancelled()) {
                     RuntimeException ex = new CancellationException("Task was cancelled: " + fut);
@@ -712,7 +712,7 @@ public class GridExecutorService extends GridMetadataAwareAdapter implements Exe
             catch (ComputeTaskTimeoutException e) {
                 throw new ExecutionException("Task execution timed out during waiting for task result: " + fut, e);
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 // Task cancellation may cause throwing exception.
                 if (fut.isCancelled()) {
                     RuntimeException ex = new CancellationException("Task was cancelled: " + fut);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/ggfs/common/GridGgfsControlResponse.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/ggfs/common/GridGgfsControlResponse.java b/modules/core/src/main/java/org/gridgain/grid/kernal/ggfs/common/GridGgfsControlResponse.java
index df1ce3f..a979f4e 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/ggfs/common/GridGgfsControlResponse.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/ggfs/common/GridGgfsControlResponse.java
@@ -287,7 +287,7 @@ public class GridGgfsControlResponse extends GridGgfsMessage {
     /**
      * @param e Error if occurred.
      */
-    public void error(IgniteCheckedException e) {
+    public void error(IgniteException e) {
         err = e.getMessage();
         errCode = errorCode(e);
     }
@@ -311,7 +311,7 @@ public class GridGgfsControlResponse extends GridGgfsMessage {
      * @param e Exception to analyze.
      * @return Error code.
      */
-    private int errorCode(IgniteCheckedException e) {
+    private int errorCode(IgniteException e) {
         return errorCode(e, true);
     }
 
@@ -323,7 +323,7 @@ public class GridGgfsControlResponse extends GridGgfsMessage {
      * @return Error code.
      */
     @SuppressWarnings("unchecked")
-    private int errorCode(IgniteCheckedException e, boolean checkIo) {
+    private int errorCode(IgniteException e, boolean checkIo) {
         if (X.hasCause(e, IgniteFsFileNotFoundException.class))
             return ERR_FILE_NOT_FOUND;
         else if (IgniteFsPathAlreadyExistsException.class.isInstance(e))

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxLocalAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxLocalAdapter.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxLocalAdapter.java
index 0f46d1c..e64da29 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxLocalAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxLocalAdapter.java
@@ -835,7 +835,7 @@ public abstract class GridCacheTxLocalAdapter<K, V> extends GridCacheTxAdapter<K
                             throw ex;
                         }
                         else {
-                            IgniteCheckedException err = new GridCacheTxHeuristicException("Failed to locally write to cache " +
+                            IgniteException err = new GridCacheTxHeuristicException("Failed to locally write to cache " +
                                 "(all transaction entries will be invalidated, however there was a window when " +
                                 "entries for this transaction were visible to others): " + this, ex);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxProxyImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxProxyImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxProxyImpl.java
index e51ef0f..4e61db6 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxProxyImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/GridCacheTxProxyImpl.java
@@ -178,7 +178,7 @@ public class GridCacheTxProxyImpl<K, V> implements GridCacheTxProxy, Externaliza
     }
 
     /** {@inheritDoc} */
-    @Override public void close() throws IgniteException {
+    @Override public void close() throws IgniteCheckedException {
         enter();
 
         try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java
index 9a3caee..3f31a46 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java
@@ -174,7 +174,7 @@ public final class GridDhtTxFinishFuture<K, V> extends GridCompoundIdentityFutur
                 catch (GridCacheTxHeuristicException ignore) {
                     // Future should complete with GridCacheTxHeuristicException.
                 }
-                catch (IgniteCheckedException err) {
+                catch (IgniteException err) {
                     U.error(log, "Failed to invalidate transaction: " + tx, err);
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/GridCacheDistributedQueryManager.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/GridCacheDistributedQueryManager.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/GridCacheDistributedQueryManager.java
index b9d2474..093ccc7 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/GridCacheDistributedQueryManager.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/GridCacheDistributedQueryManager.java
@@ -373,7 +373,7 @@ public class GridCacheDistributedQueryManager<K, V> extends GridCacheQueryManage
             try {
                 fut.cancel();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 U.error(log, "Failed to cancel running query future: " + fut, e);
             }
 
@@ -389,7 +389,7 @@ public class GridCacheDistributedQueryManager<K, V> extends GridCacheQueryManage
             try {
                 fut.get();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 if (log.isDebugEnabled())
                     log.debug("Received query error while waiting for query to finish [queryFuture= " + fut +
                         ", error= " + e + ']');

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAsyncImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAsyncImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAsyncImpl.java
index ee1b4a5..7479c56 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAsyncImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAsyncImpl.java
@@ -14,6 +14,7 @@ import org.apache.ignite.fs.*;
 import org.apache.ignite.fs.mapreduce.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 import java.net.*;
@@ -42,7 +43,12 @@ public class GridGgfsAsyncImpl extends IgniteAsyncSupportAdapter implements Grid
 
     /** {@inheritDoc} */
     @Override public void format() throws IgniteException {
-        saveOrGet(ggfs.formatAsync());
+        try {
+            saveOrGet(ggfs.formatAsync());
+        }
+        catch (IgniteCheckedException e) {
+            throw U.wrap(e);
+        }
     }
 
     /** {@inheritDoc} */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsInputStreamImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsInputStreamImpl.java
index d34c4c8..86bbda5 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsInputStreamImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsInputStreamImpl.java
@@ -277,7 +277,7 @@ public class GridGgfsInputStreamImpl extends GridGgfsInputStreamAdapter {
                     try {
                         fut.get();
                     }
-                    catch (IgniteCheckedException ignore) {
+                    catch (IgniteException ignore) {
                         // No-op.
                     }
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsMetaManager.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsMetaManager.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsMetaManager.java
index 7ea2c03..77e9dda 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsMetaManager.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsMetaManager.java
@@ -74,12 +74,7 @@ public class GridGgfsMetaManager extends GridGgfsManager {
      */
     void awaitInit() {
         if (!metaCacheStartFut.isDone()) {
-            try {
-                metaCacheStartFut.get();
-            }
-            catch (IgniteCheckedException e) {
-                throw new IgniteException(e);
-            }
+            metaCacheStartFut.get();
         }
     }
 
@@ -1674,7 +1669,7 @@ public class GridGgfsMetaManager extends GridGgfsManager {
 
                                                 evts.record(new IgniteFsEvent(path, locNode, EVT_GGFS_FILE_PURGED));
                                             }
-                                            catch (IgniteCheckedException e) {
+                                            catch (IgniteException e) {
                                                 LT.warn(log, e, "Old file deletion failed in DUAL mode [path=" + path +
                                                     ", simpleCreate=" + simpleCreate + ", props=" + props +
                                                     ", overwrite=" + overwrite + ", bufferSize=" + bufSize +

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsServer.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsServer.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsServer.java
index ac5b3f3..49809eb 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsServer.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsServer.java
@@ -259,7 +259,7 @@ public class GridGgfsServer {
                             try {
                                 res = fut.get();
                             }
-                            catch (IgniteCheckedException e) {
+                            catch (IgniteException e) {
                                 res = new GridGgfsControlResponse();
 
                                 ((GridGgfsControlResponse)res).error(e);
@@ -287,7 +287,7 @@ public class GridGgfsServer {
                                     try {
                                         res = fut.get();
                                     }
-                                    catch (IgniteCheckedException e) {
+                                    catch (IgniteException e) {
                                         res = new GridGgfsControlResponse();
 
                                         ((GridGgfsControlResponse)res).error(e);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/IgniteFsOutputStreamImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/IgniteFsOutputStreamImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/IgniteFsOutputStreamImpl.java
index 04ab237..b5fa7fc 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/IgniteFsOutputStreamImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/IgniteFsOutputStreamImpl.java
@@ -335,7 +335,7 @@ class IgniteFsOutputStreamImpl extends IgniteFsOutputStreamAdapter {
 
                     writeCompletionFut.get();
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     err = new IOException("Failed to close stream [path=" + path + ", fileInfo=" + fileInfo + ']', e);
                 }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/rest/handlers/cache/GridCacheQueryCommandHandler.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/rest/handlers/cache/GridCacheQueryCommandHandler.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/rest/handlers/cache/GridCacheQueryCommandHandler.java
index 3303b41..b7999b5 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/rest/handlers/cache/GridCacheQueryCommandHandler.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/rest/handlers/cache/GridCacheQueryCommandHandler.java
@@ -124,7 +124,7 @@ public class GridCacheQueryCommandHandler extends GridRestCommandHandlerAdapter
 
                 return comp.future();
             }
-            catch (IgniteCheckedException e) {
+            catch (IgniteException e) {
                 // Should not be thrown since uses asynchronous execution.
                 return new GridFinishedFutureEx<>(e);
             }
@@ -151,13 +151,13 @@ public class GridCacheQueryCommandHandler extends GridRestCommandHandlerAdapter
 
                         return new GridRestResponse();
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         throw new GridClosureException(e);
                     }
                 }
             });
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             // Should not be thrown since uses asynchronous execution.
             return new GridFinishedFutureEx<>(e);
         }
diff --git a/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java b/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java
index 1235c4b..0689f26 100644
--- a/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java
+++ b/modules/core/src/main/java/org/apache/ignite/messaging/MessagingListenActor.java
@@ -154,9 +154,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      *
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
      * @throws IgniteCheckedException Thrown in case of any errors.
      */
-    protected final void respond(@Nullable Object respMsg) throws IgniteCheckedException {
+    protected final void respond(@Nullable Object respMsg) throws IgniteException {
         checkReversing();
 
         keepGoing = true;
@@ -174,9 +174,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param id ID of the node to send the message to, if any.
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
      * @throws IgniteCheckedException Thrown in case of any errors.
      */
-    protected final void respond(UUID id, @Nullable Object respMsg) throws IgniteCheckedException {
+    protected final void respond(UUID id, @Nullable Object respMsg) throws IgniteException {
         checkReversing();
 
         keepGoing = true;
@@ -198,9 +198,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      *
      * @param nodeId ID of the node to send message to.
      * @param respMsg Message to send.
      * @throws IgniteCheckedException Thrown in case of any errors.
      */
-    private void send(UUID nodeId, @Nullable Object respMsg) throws IgniteCheckedException {
+    private void send(UUID nodeId, @Nullable Object respMsg) throws IgniteException {
         assert nodeId != null;
 
         if (respMsg != null) {
@@ -209,7 +209,7 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
             if (node != null)
                 ignite.message(ignite.cluster().forNode(node)).send(null, respMsg); // Can still fail.
             else
-                throw new IgniteCheckedException("Failed to send message since destination node has " +
+                throw new IgniteException("Failed to send message since destination node has " +
                     "left topology (ignoring) [nodeId=" +nodeId + ", respMsg=" + respMsg + ']');
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsCheckpointSpi.java
----------------------------------------------------------------------
@@ -154,9 +154,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
@@ -174,9 +174,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param respMsg Optional response message. If not {@code null} - it will be sent to the original
      *      sender node.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
@@ -198,9 +198,9 @@ public abstract class MessagingListenActor<T> implements IgniteBiPredicate<UUID,
      * @param nodeId ID of the node to send message to.
      * @param respMsg Message to send.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/streamer/index/tree/StreamerTreeIndexProvider.java b/modules/core/src/main/java/org/apache/ignite/streamer/index/tree/StreamerTreeIndexProvider.java
index a9a81a4..4c188b8 100644
--- a/modules/core/src/main/java/org/apache/ignite/streamer/index/tree/StreamerTreeIndexProvider.java
+++ b/modules/core/src/main/java/org/apache/ignite/streamer/index/tree/StreamerTreeIndexProvider.java
@@ -129,7 +129,7 @@ public class StreamerTreeIndexProvider<E, K, V> extends StreamerIndexProviderAda
 
             if (isUnique()) {
                 if (old != null)
-                    throw new IgniteCheckedException("Index unique key violation [evt=" + evt + ", key=" + key +
+                    throw new IgniteException("Index unique key violation [evt=" + evt + ", key=" + key +
                         ", idxKey=" + idxKey + ']');
             }
             else
@@ -190,7 +190,7 @@ public class StreamerTreeIndexProvider<E, K, V> extends StreamerIndexProviderAda
 
                 if (isUnique()) {
                     if (old != null)
-                        throw new IgniteCheckedException("Index unique key violation [evt=" + evt + ", key=" + key +
+                        throw new IgniteException("Index unique key violation [evt=" + evt + ", key=" + key +
                             ", idxKey=" + newIdxKey + ']');
                 }
                 else
@@ -285,7 +285,7 @@ public class StreamerTreeIndexProvider<E, K, V> extends StreamerIndexProviderAda
 
                 if (isUnique()) {
                     if (old != null)
-                        throw new IgniteCheckedException("Index unique key violation [evt=" + evt + ", key=" + key +
+                        throw new IgniteException("Index unique key violation [evt=" + evt + ", key=" + key +
                             ", idxKey=" + newIdxKey + ']');
                 }
                 else
@@ -310,10 +310,10 @@ public class StreamerTreeIndexProvider<E, K, V> extends StreamerIndexProviderAda
      * @param key2 Key.
      * @param order Keys comparison result.
      * @param sync Sync.
      * @throws IgniteCheckedException If interrupted.
      */
     private void lockKeys(IndexKey<V> key1, IndexKey<V> key2, int order, StreamerIndexUpdateSync sync)
-        throws IgniteCheckedException {
+        throws IgniteException {
         assert isUnique();
         assert key1 != null;
         assert key2 != null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/apache/ignite/streamer/window/StreamerBoundedTimeWindow.java
----------------------------------------------------------------------
@@ -310,10 +310,10 @@ public class StreamerTreeIndexProvider<E, K, V> extends StreamerIndexProviderAda
      * @param order Keys comparison result.
      * @param sync Sync.
-     * @throws IgniteCheckedException If interrupted.
+     * @throws IgniteException If interrupted.
      */
     private void lockKeys(IndexKey<V> key1, IndexKey<V> key2, int order, StreamerIndexUpdateSync sync)
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsImpl.java
index 214191e..9599a32 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsImpl.java
@@ -470,27 +470,32 @@ public final class GridGgfsImpl implements GridGgfsEx {
         IgniteFsMode mode = modeRslvr.resolveMode(path);
 
         if (mode == PROXY)
-            throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+            throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
 
         boolean res = false;
 
-        switch (mode) {
-            case PRIMARY:
-                res = meta.fileId(path) != null;
+        try {
+            switch (mode) {
+                case PRIMARY:
+                    res = meta.fileId(path) != null;
 
-                break;
+                    break;
 
-            case DUAL_SYNC:
-            case DUAL_ASYNC:
-                res = meta.fileId(path) != null;
+                case DUAL_SYNC:
+                case DUAL_ASYNC:
+                    res = meta.fileId(path) != null;
 
-                if (!res)
-                    res = secondaryFs.exists(path);
+                    if (!res)
+                        res = secondaryFs.exists(path);
 
-                break;
+                    break;
 
-            default:
-                assert false : "Unknown mode.";
+                default:
+                    assert false : "Unknown mode.";
+            }
+        }
+        catch (IgniteCheckedException e) {
+            throw U.wrap(e);
         }
 
         return res;
@@ -508,7 +513,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 IgniteFsMode mode = modeRslvr.resolveMode(path);
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
 
                 GridGgfsFileInfo info = resolveFileInfo(path, mode);
 
@@ -545,6 +550,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
                 return sum;
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -567,7 +575,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 IgniteFsMode mode = modeRslvr.resolveMode(path);
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
                 else if (mode != PRIMARY) {
                     assert mode == DUAL_SYNC || mode == DUAL_ASYNC;
 
@@ -601,6 +609,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 else
                     return null;
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -623,7 +634,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 Set<IgniteFsMode> childrenModes = modeRslvr.resolveChildrenModes(src);
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + src);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + src);
 
                 if (src.equals(dest))
                     return; // Rename to itself is a no-op.
@@ -710,6 +721,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
                         evts.record(new IgniteFsEvent(src, dest, localNode(), EVT_GGFS_DIR_RENAMED));
                 }
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -764,6 +778,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
                 return res;
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -834,7 +851,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 IgniteFsMode mode = modeRslvr.resolveMode(path);
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
                 else if (mode != PRIMARY) {
                     assert mode == DUAL_SYNC || mode == DUAL_ASYNC;
 
@@ -898,6 +915,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
                     parentId = fileId;
                 }
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -918,7 +938,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 IgniteFsMode mode = modeRslvr.resolveMode(path);
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
 
                 Set<IgniteFsMode> childrenModes = modeRslvr.resolveChildrenModes(path);
 
@@ -950,6 +970,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
                     }
                 });
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -970,7 +993,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 IgniteFsMode mode = modeRslvr.resolveMode(path);
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
 
                 Set<IgniteFsMode> childrenModes = modeRslvr.resolveChildrenModes(path);
 
@@ -1017,6 +1040,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
                 return files;
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -1063,7 +1089,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 IgniteFsMode mode = modeRslvr.resolveMode(path);
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
                 else if (mode != PRIMARY) {
                     assert mode == DUAL_SYNC || mode == DUAL_ASYNC;
 
@@ -1098,6 +1124,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
                 return os;
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -1145,7 +1174,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
         final int replication,
         @Nullable Map<String, String> props,
         final boolean simpleCreate
-    ) throws IgniteCheckedException {
+    ) throws IgniteException {
         if (enterBusy()) {
             try {
                 A.notNull(path, "path");
@@ -1160,7 +1189,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 GridGgfsFileWorkerBatch batch = null;
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
                 else if (mode != PRIMARY) {
                     assert mode == DUAL_SYNC || mode == DUAL_ASYNC;
 
@@ -1239,6 +1268,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
                 return os;
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -1269,7 +1301,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 GridGgfsFileWorkerBatch batch = null;
 
                 if (mode == PROXY)
-                    throw new IgniteCheckedException("PROXY mode cannot be used in GGFS directly: " + path);
+                    throw new IgniteException("PROXY mode cannot be used in GGFS directly: " + path);
                 else if (mode != PRIMARY) {
                     assert mode == DUAL_SYNC || mode == DUAL_ASYNC;
 
@@ -1323,6 +1355,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
                 return new GgfsEventAwareOutputStream(path, info, parentId, bufSize == 0 ?
                     cfg.getStreamBufferSize() : bufSize, mode, batch);
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -1355,6 +1390,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
                 meta.updateTimes(desc.parentId, desc.fileId, desc.fileName, accessTime, modificationTime);
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -1422,6 +1460,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
                 return data.affinity(info, start, len, maxLen);
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -1444,7 +1485,7 @@ public final class GridGgfsImpl implements GridGgfsEx {
                     try {
                         secondarySpaceSize = secondaryFs.usedSpaceSize();
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         LT.warn(log, e, "Failed to get secondary file system consumed space size.");
 
                         secondarySpaceSize = -1;
@@ -1468,6 +1509,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
                     metrics.writeBytes(),
                     metrics.writeBytesTime());
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -1498,6 +1542,9 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
                 return sum.totalLength();
             }
+            catch (IgniteCheckedException e) {
+                throw U.wrap(e);
+            }
             finally {
                 busyLock.leaveBusy();
             }
@@ -1535,7 +1582,12 @@ public final class GridGgfsImpl implements GridGgfsEx {
 
     /** {@inheritDoc} */
     @Override public void format() throws IgniteException {
-        formatAsync().get();
+        try {
+            formatAsync().get();
+        }
+        catch (IgniteCheckedException e) {
+            throw U.wrap(e);
+        }
     }
 
     /**
@@ -1781,37 +1833,42 @@ public final class GridGgfsImpl implements GridGgfsEx {
      * @param path Path.
      * @param mode Mode.
      * @return File info or {@code null} in case file is not found.
      * @throws IgniteCheckedException If failed.
      */
-    private GridGgfsFileInfo resolveFileInfo(IgniteFsPath path, IgniteFsMode mode) throws IgniteCheckedException {
+    private GridGgfsFileInfo resolveFileInfo(IgniteFsPath path, IgniteFsMode mode) throws IgniteException {
         assert path != null;
         assert mode != null;
 
         GridGgfsFileInfo info = null;
 
-        switch (mode) {
-            case PRIMARY:
-                info = meta.info(meta.fileId(path));
+        try {
+            switch (mode) {
+                case PRIMARY:
+                    info = meta.info(meta.fileId(path));
 
-                break;
+                    break;
 
-            case DUAL_SYNC:
-            case DUAL_ASYNC:
-                info = meta.info(meta.fileId(path));
+                case DUAL_SYNC:
+                case DUAL_ASYNC:
+                    info = meta.info(meta.fileId(path));
 
-                if (info == null) {
-                    IgniteFsFile status = secondaryFs.info(path);
+                    if (info == null) {
+                        IgniteFsFile status = secondaryFs.info(path);
 
-                    if (status != null)
-                        info = status.isDirectory() ? new GridGgfsFileInfo(true, status.properties()) :
-                            new GridGgfsFileInfo(status.blockSize(), status.length(), null, null, false,
-                            status.properties());
-                }
+                        if (status != null)
+                            info = status.isDirectory() ? new GridGgfsFileInfo(true, status.properties()) :
+                                new GridGgfsFileInfo(status.blockSize(), status.length(), null, null, false,
+                                status.properties());
+                    }
 
-                break;
+                    break;
 
-            default:
-                assert false : "Unknown mode: " + mode;
+                default:
+                    assert false : "Unknown mode: " + mode;
+            }
+        }
+        catch (IgniteCheckedException e) {
+            throw U.wrap(e);
         }
 
         return info;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/4307bca1/modules/core/src/main/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsInputStreamImpl.java
----------------------------------------------------------------------
@@ -1781,37 +1833,42 @@ public final class GridGgfsImpl implements GridGgfsEx {
      * @param mode Mode.
      * @return File info or {@code null} in case file is not found.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */